@@ -29,10 +29,10 @@ if (ovs_vsctl --version) > /dev/null 2>&1; then :; else
     exit 0
 fi
 
-SERVICE_UNIT=/usr/lib/systemd/system/openvswitch-nonetwork.service
-if [ -f $SERVICE_UNIT ] && [ -x /usr/bin/systemctl ]; then
-    if ! systemctl --quiet is-active openvswitch-nonetwork.service; then
-        systemctl start openvswitch-nonetwork.service
+SERVICE_UNIT=/lib/systemd/system/openvswitch-switch.service
+if [ -f $SERVICE_UNIT ] && [ -x /bin/systemctl ]; then
+    if ! systemctl --quiet is-active openvswitch-switch.service; then
+        systemctl start openvswitch-switch.service
     fi
 else
     if service openvswitch-switch status > /dev/null 2>&1; then
@@ -77,6 +77,12 @@ if [ "${MODE}" = "start" ]; then
                     ifconfig "${slave}" up
                 done
                 ;;
+        OVSPatchPort)
+                ovs_vsctl -- --may-exist add-port "${IF_OVS_BRIDGE}"\
+                    "${IFACE}" ${IF_OVS_OPTIONS} -- set Interface "${IFACE}" \
+                    type=patch options:peer="${IF_OVS_PATCH_PEER}" \
+                    ${OVS_EXTRA+-- $OVS_EXTRA}
+                ;;
         OVSTunnel)
                 ovs_vsctl -- --may-exist add-port "${IF_OVS_BRIDGE}"\
                     "${IFACE}" ${IF_OVS_OPTIONS} -- set Interface "${IFACE}" \
@@ -96,7 +102,7 @@ elif [ "${MODE}" = "stop" ]; then
 
                 ovs_vsctl -- --if-exists del-br "${IFACE}"
                 ;;
-        OVSPort|OVSIntPort|OVSBond|OVSTunnel)
+        OVSPort|OVSIntPort|OVSBond|OVSPatchPort|OVSTunnel)
                 ovs_vsctl -- --if-exists del-port "${IF_OVS_BRIDGE}" "${IFACE}"
                 ;;
         *)
